==> staging_cacao_accounting-0.0.2rc20240609.tar.gz: staging_cacao_accounting-0.0.2rc20240609/README.md <==
![Logo](https://raw.githubusercontent.com/cacao-accounting/cacao-accounting/main/cacao_accounting/static/media/Cacao%20Accounting-01.png)

# Cacao Accounting

![PyPI - License](https://img.shields.io/pypi/l/cacao-accounting?color=green&logo=apache)
[![Pruebas de Integración Continua](https://github.com/cacao-accounting/cacao-accounting/actions/workflows/python-package.yml/badge.svg)](https://github.com/cacao-accounting/cacao-accounting/actions/workflows/python-package.yml)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cacao-accounting?logo=pypi)
![Pypi](https://img.shields.io/pypi/v/cacao-accounting?color=Blue&label=Version&logo=pypi)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/cacao-accounting?logo=pypi)
[![Docker Repository on Quay](https://quay.io/repository/cacaoaccounting/cacaoaccounting/status "Docker Repository on Quay")](https://quay.io/repository/cacaoaccounting/cacaoaccounting)
[![codecov](https://codecov.io/gh/cacao-accounting/cacao-accounting/branch/development/graph/badge.svg)](https://codecov.io/gh/cacao-accounting/cacao-accounting)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=cacao-accounting_cacao-accounting&metric=alert_status)](https://sonarcloud.io/dashboard?id=cacao-accounting_cacao-accounting)
[![Gitter](https://badges.gitter.im/cacao-accounting/community.svg)](https://gitter.im/cacao-accounting/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

Solución contable para la gestión de Cuentas por Cobrar, Cuentas por Cobrar, Inventario, Tesorería y Contabilidad General. 

Nota: 
* Este es un proyecto en etapa temprana de desarrollo no apta para uso en producción.
* Hemos definido una serie de [metas y objetivos](https://cacao-accounting.github.io/cacao-accounting/ROAD_MAP/) para el proyecto.

Este proyecto surge de la necesidad observada en Nicaragua de contar con una solucion de software para que micro, pequeñas y medianas empresas (Pymes) cuenten con una herramienta para el procesamiento contable de sus actividades. 
Dado el costo de soluciones de software ya existentes muchas Pymes obtan por usar software pirata que casi de forma
inevitable termina en una falla del software utilizado y perdida de datos. Otras empresas asumen que al contratar a
un profesional contable este debe de contar por defecto con una herramienta para llevar la contabilidad de la entidad,
el objetivo principal de este proyecto es proveeder de una herramienta confiable para el procesamiento contable de las
operaciones de una o varias entidades.

Reconocemos que ya existen opciones de soluciones de software contable robustas desarrolladas en python como lo son
[Odoo](https://www.odoo.com/es_ES/), [Tryton](https://www.tryton.org/) y [ERPNext](https://erpnext.com/). Sin embargo
estas herramientas requieren o el pago de una suscripción o la instalación de un servidor web, por lo que mayoria de
profesionales contables no podrian implementarlos sin requerir asistencia de un administrador de sistemas, por esto uno
de los objetivos de este proyecto es ofrecer tanto una solución de escritorio para un solo usuario así como una solución
web que pueder ser usada por multiples usuarios al mismo tiempo.

Consideramos que una ves el proyecto sea un producto usable puede tener potencial economico, no mediante el modelo
de negocios de licenciamiento, si no con servicios conexos como implementación, capacitación, hospedaje en la nube y mantenimiento

## Participar en el Proyecto:

Todos los aportes son bienvenidos, ver el archivo [CONTRIBUTING](https://cacao-accounting.github.io/cacao-accounting/CONTRIBUTING/) para mas detalles.

## Licencia.

Derechos de autor 2024 William José Moreno Reyes

Autorizado en virtud de la Licencia de Apache, Versión 2.0 (la "Licencia"); se
prohíbe utilizar este archivo excepto en cumplimiento de la Licencia. Podrá
obtener una copia de la Licencia en:

  http://www.apache.org/licenses/LICENSE-2.0

A menos que lo exijan las leyes pertinentes o se haya establecido por escrito,
el software distribuido en virtud de la Licencia se distribuye “TAL CUAL”, SIN
GARANTÍAS NI CONDICIONES DE NINGÚN TIPO, ya sean expresas o implícitas. Véase
la Licencia para consultar el texto específico relativo a los permisos y
limitaciones establecidos en la Licencia.

==> staging_cacao_accounting-0.0.3rc20240719.tar.gz: staging_cacao_accounting-0.0.3rc20240719/README.md <==
![Logo](https://raw.githubusercontent.com/cacao-accounting/cacao-accounting/main/cacao_accounting/static/media/Cacao%20Accounting-01.png)

# Cacao Accounting

[![Pruebas de Integración Continua](https://github.com/cacao-accounting/cacao-accounting/actions/workflows/python-package.yml/badge.svg)](https://github.com/cacao-accounting/cacao-accounting/actions/workflows/python-package.yml)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=cacao-accounting_cacao-accounting&metric=alert_status)](https://sonarcloud.io/dashboard?id=cacao-accounting_cacao-accounting)
[![Coverage Status](https://coveralls.io/repos/github/cacao-accounting/cacao-accounting/badge.svg?branch=main)](https://coveralls.io/github/cacao-accounting/cacao-accounting?branch=main)
![PyPI - License](https://img.shields.io/pypi/l/cacao-accounting?color=green&logo=apache)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/staging-cacao-accounting?logo=Python&color=gree&link=https%3A%2F%2Fpypi.org%2Fproject%2Fstaging-cacao-accounting%2F)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/staging-cacao-accounting?logo=Python)
[![Docker Repository on Quay](https://quay.io/repository/cacaoaccounting/cacaoaccounting/status "Docker Repository on Quay")](https://quay.io/repository/cacaoaccounting/cacaoaccounting)
[![Gitter](https://badges.gitter.im/cacao-accounting/community.svg)](https://gitter.im/cacao-accounting/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

Solución contable para la gestión de Cuentas por Cobrar, Cuentas por Cobrar, Inventario, Tesorería y Contabilidad General. 

```
Live demo at:
URL: https://cacao-accounting.onrender.com/login
User: cacao
Password: cacao

Wait to the free render instance to wake up.
```


Nota: 
* Este es un proyecto en etapa temprana de desarrollo no apta para uso en producción.
* Hemos definido una serie de [metas y objetivos](https://cacao-accounting.github.io/cacao-accounting/ROAD_MAP/) para el proyecto.

Este proyecto surge de la necesidad observada en Nicaragua de contar con una solucion de software para que micro, pequeñas y medianas empresas (Pymes) cuenten con una herramienta para el procesamiento contable de sus actividades. 
Dado el costo de soluciones de software ya existentes muchas Pymes obtan por usar software pirata que casi de forma
inevitable termina en una falla del software utilizado y perdida de datos. Otras empresas asumen que al contratar a
un profesional contable este debe de contar por defecto con una herramienta para llevar la contabilidad de la entidad,
el objetivo principal de este proyecto es proveeder de una herramienta confiable para el procesamiento contable de las
operaciones de una o varias entidades.

Reconocemos que ya existen opciones de soluciones de software contable robustas desarrolladas en python como lo son
[Odoo](https://www.odoo.com/es_ES/), [Tryton](https://www.tryton.org/) y [ERPNext](https://erpnext.com/). Sin embargo
estas herramientas requieren o el pago de una suscripción o la instalación de un servidor web, por lo que mayoria de
profesionales contables no podrian implementarlos sin requerir asistencia de un administrador de sistemas, por esto uno
de los objetivos de este proyecto es ofrecer tanto una solución de escritorio para un solo usuario así como una solución
web que pueder ser usada por multiples usuarios al mismo tiempo.

Consideramos que una ves el proyecto sea un producto usable puede tener potencial economico, no mediante el modelo
de negocios de licenciamiento, si no con servicios conexos como implementación, capacitación, hospedaje en la nube y mantenimiento

## Participar en el Proyecto:

Todos los aportes son bienvenidos, ver el archivo [CONTRIBUTING](https://cacao-accounting.github.io/cacao-accounting/CONTRIBUTING/) para mas detalles.

## Licencia.

Derechos de autor 2024 William José Moreno Reyes

Autorizado en virtud de la Licencia de Apache, Versión 2.0 (la "Licencia"); se
prohíbe utilizar este archivo excepto en cumplimiento de la Licencia. Podrá
obtener una copia de la Licencia en:

  http://www.apache.org/licenses/LICENSE-2.0

A menos que lo exijan las leyes pertinentes o se haya establecido por escrito,
el software distribuido en virtud de la Licencia se distribuye “TAL CUAL”, SIN
GARANTÍAS NI CONDICIONES DE NINGÚN TIPO, ya sean expresas o implícitas. Véase
la Licencia para consultar el texto específico relativo a los permisos y
limitaciones establecidos en la Licencia.
